@@ -363,7 +363,9 @@ def check_resource(resource, get_method, query_string='', wait_time=1,
     def get_kwargs(resource_id):
         if not (EVALUATION_RE.match(resource_id) or
                 PREDICTION_RE.match(resource_id) or
-                BATCH_PREDICTION_RE.match(resource_id)):
+                BATCH_PREDICTION_RE.match(resource_id) or
+                CENTROID_RE.match(resource_id) or
+                BATCH_CENTROID_RE.match(resource_id)):
             return {'query_string': query_string}
         return {}
 
@@ -719,6 +721,7 @@ class BigML(object):
             response = requests.get(url + auth + query_string,
                                     headers=ACCEPT_JSON,
                                     verify=VERIFY)
+
             code = response.status_code
 
             if code == HTTP_OK:
